@@ -18,7 +18,7 @@ def help():
     print(" torancell.bogo(int)")
     print(" torancell.wiki()")
     print(" torancell.weather()")
-    print(" torancell.mail("your mailaddress")")
+    print(" torancell.mail(\"your mailaddress\")")
     print(" list = torancell.handgen()")
     print(" torancell.shantenquiz()")
     print(" torancell.tenhou(step)")
